@@ -251,7 +251,6 @@ EXCLUDE = (
     "lib/fdpgen/grid.c",
     "lib/fdpgen/grid.h",
     "lib/fdpgen/layout.c",
-    "lib/fdpgen/tlayout.c",
     "lib/fdpgen/tlayout.h",
     "lib/fdpgen/xlayout.c",
     "lib/fdpgen/xlayout.h",
@@ -325,8 +324,6 @@ EXCLUDE = (
     "lib/mingle/nearest_neighbor_graph_ann.cpp",
     "lib/neatogen/adjust.c",
     "lib/neatogen/adjust.h",
-    "lib/neatogen/bfs.c",
-    "lib/neatogen/bfs.h",
     "lib/neatogen/call_tri.c",
     "lib/neatogen/call_tri.h",
     "lib/neatogen/circuit.c",
@@ -359,8 +356,6 @@ EXCLUDE = (
     "lib/neatogen/matinv.c",
     "lib/neatogen/matrix_ops.c",
     "lib/neatogen/matrix_ops.h",
-    "lib/neatogen/mem.h",
-    "lib/neatogen/memory.c",
     "lib/neatogen/multispline.c",
     "lib/neatogen/multispline.h",
     "lib/neatogen/neato.h",
@@ -541,6 +536,8 @@ EXCLUDE = (
     "plugin/pango/gvrender_pango.c",
     "plugin/pango/gvtextlayout_pango.c",
     "plugin/poppler/gvloadimage_poppler.c",
+    "plugin/quartz/GVTextLayout.h",
+    "plugin/quartz/GVTextLayout.m",
     "plugin/quartz/gvdevice_quartz.c",
     "plugin/quartz/gvloadimage_quartz.c",
     "plugin/quartz/gvplugin_quartz.c",
