@@ -8,17 +8,17 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include <cgraph/cgraph.h>
-#include <cgraph/exit.h>
-#include <ingraphs/ingraphs.h>
+#include <cgraph/ingraphs.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <util/exit.h>
 
 #include <getopt.h>
 
