@@ -21,8 +21,6 @@
 #include <stdlib.h>
 #include <util/alloc.h>
 
-Agraph_t *Ag_G_global;
-
 /*
  * this code sets up the resource management discipline
  * and returns a new main graph struct.
@@ -69,17 +67,13 @@ Agraph_t *agopen1(Agraph_t * g)
 {
     Agraph_t *par;
 
-    g->n_seq = agdtopen(g, &Ag_subnode_seq_disc, Dttree);
+    g->n_seq = agdtopen(&Ag_subnode_seq_disc, Dttree);
     g->n_id = node_set_new();
-    g->e_seq = agdtopen(g, g == agroot(g)? &Ag_mainedge_seq_disc : &Ag_subedge_seq_disc, Dttree);
-    g->e_id = agdtopen(g, g == agroot(g)? &Ag_mainedge_id_disc : &Ag_subedge_id_disc, Dttree);
-    g->g_seq = agdtopen(g, &Ag_subgraph_seq_disc, Dttree);
+    g->e_seq = agdtopen(g == agroot(g)? &Ag_mainedge_seq_disc : &Ag_subedge_seq_disc, Dttree);
+    g->e_id = agdtopen(g == agroot(g)? &Ag_mainedge_id_disc : &Ag_subedge_id_disc, Dttree);
+    g->g_seq = agdtopen(&Ag_subgraph_seq_disc, Dttree);
 
-    // `agdtopen` has allocated a `Dt_t`, which we now expand to host a
-    // `g_seq_t`. See `g_seq_t` for why we do this odd thing.
-    g->g_seq = gv_realloc(g->g_seq, sizeof(Dt_t), sizeof(g_seq_t));
-
-    g->g_id = agdtopen(g, &Ag_subgraph_id_disc, Dttree);
+    g->g_id = agdtopen(&Ag_subgraph_id_disc, Dttree);
 
     par = agparent(g);
     if (par) {
@@ -87,7 +81,6 @@ Agraph_t *agopen1(Agraph_t * g)
 	assert((seq & SEQ_MASK) == seq && "sequence ID overflow");
 	AGSEQ(g) = seq & SEQ_MASK;
 	dtinsert(par->g_seq, g);
-	Agraphs_append(g_seq2(par), g);
 	dtinsert(par->g_id, g);
     }
     if (!par || par->desc.has_attrs)
@@ -129,11 +122,6 @@ int agclose(Agraph_t * g)
     assert(dtsize(g->e_seq) == 0);
     if (agdtclose(g, g->e_seq)) return FAILURE;
 
-    // needs to be done before closing `g_seq` because `agdtclose(g, g->g_seq)`
-    // deallocates the memory this is hosted in
-    assert(Agraphs_is_empty(g_seq2(g)));
-    Agraphs_free(g_seq2(g));
-
     assert(dtsize(g->g_seq) == 0);
     if (agdtclose(g, g->g_seq)) return FAILURE;
 
@@ -147,16 +135,14 @@ int agclose(Agraph_t * g)
 
     if (par) {
 	agdelsubg(par, g);
-	agfree(par, g);
+	free(g);
     } else {
-	void *clos;
 	while (g->clos->cb)
 	    agpopdisc(g, g->clos->cb->f);
 	AGDISC(g, id)->close(AGCLOS(g, id));
 	if (agstrclose(g)) return FAILURE;
-	clos = g->clos;
+	free(g->clos);
 	free(g);
-	free(clos);
     }
     return SUCCESS;
 }
