@@ -1,9 +1,15 @@
+/**
+ * @file
+ * @brief implementation of subgraphs
+ * @ingroup cgraph_subgraph
+ * @ingroup cgraph_core
+ */
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -11,6 +17,7 @@
 #include <cgraph/cghdr.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
 
 static Agraph_t *agfindsubg_by_id(Agraph_t * g, IDTYPE id)
 {
@@ -29,7 +36,7 @@ static Agraph_t *localsubg(Agraph_t * g, IDTYPE id)
     if (subg)
 	return subg;
 
-    subg = agalloc(g, sizeof(Agraph_t));
+    subg = gv_alloc(sizeof(Agraph_t));
     subg->clos = g->clos;
     subg->desc = g->desc;
     subg->desc.maingraph = false;
@@ -39,13 +46,8 @@ static Agraph_t *localsubg(Agraph_t * g, IDTYPE id)
     return agopen1(subg);
 }
 
-Agraph_t *agidsubg(Agraph_t * g, IDTYPE id, int cflag)
-{
-    Agraph_t *subg;
-    subg = agfindsubg_by_id(g, id);
-    if (subg == NULL && cflag && agallocid(g, AGRAPH, id))
-	subg = localsubg(g, id);
-    return subg;
+Agraph_t *agidsubg(Agraph_t *g, IDTYPE id) {
+    return agfindsubg_by_id(g, id);
 }
 
 Agraph_t *agsubg(Agraph_t * g, char *name, int cflag)
@@ -91,6 +93,5 @@ Agraph_t *agparent(Agraph_t * g)
  */
 int agdelsubg(Agraph_t * g, Agraph_t * subg)
 {
-    return ( (dtdelete(g->g_seq, subg) != NULL)  &&
-        (dtdelete(g->g_id, subg) != NULL) );
+    return dtdelete(g->g_seq, subg) != NULL  && dtdelete(g->g_id, subg) != NULL;
 }
