@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -17,6 +17,7 @@
 #ifdef _WIN32
 #include "windows.h"
 #endif
+#include <stdbool.h>
 #include <stdio.h>
 #include <glcomp/opengl.h>
 #include <glcomp/glcompdefs.h>
@@ -25,13 +26,10 @@
 extern "C" {
 #endif
 
-    extern glCompTex *glCompSetAddNewTexImage(glCompSet * s, int width,
-					      int height,
-					      unsigned char *data,
-					      int is2D);
-    extern glCompTex *glCompSetAddNewTexLabel(glCompSet * s, char *def,
-					      int fs, char *text,
-					      int is2D);
+glCompTex *glCompSetAddNewTexImage(glCompSet *s, int width, int height,
+                                   const unsigned char *data, bool is2D);
+glCompTex *glCompSetAddNewTexLabel(glCompSet *s, char *def, int fs,
+                                   const char *text, bool is2D);
 
     extern void glCompDeleteTexture(glCompTex * t);
 #ifdef __cplusplus
