@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -62,63 +62,18 @@ typedef struct LeafList {
     Leaf_t *leaf;
 } LeafList_t;
 
-#ifndef METHODS
-#define METHODS 1
-#endif /*METHODS*/
     struct RTree {
     Node_t *root;
 
     SplitQ_t split;
-
-    /* balance criterion for node splitting */
-    int MinFill;
-
-    /* times */
-    long ElapsedTime;
-    float UserTime, SystemTime;
-
-    int Deleting;
-
-    /* variables for statistics */
-    int StatFlag;		/* tells if we are counting or not */
-    /* counters affected only when StatFlag set */
-    int InsertCount;
-    int DeleteCount;
-    int ReInsertCount;
-    int InSplitCount;
-    int DeSplitCount;
-    int ElimCount;
-    int EvalCount;
-    int InTouchCount;
-    int DeTouchCount;
-    int SeTouchCount;
-    int CallCount;
-    float SplitMeritSum;
-
-    /* counters used even when StatFlag not set */
-    int RectCount;
-    int NodeCount;
-    int LeafCount, NonLeafCount;
-    int EntryCount;
-    int SearchCount;
-    int HitCount;
-
 };
 
-typedef struct ListNode {
-    struct ListNode *next;
-    struct Node *node;
-} ListNode_t;
-
 RTree_t *RTreeOpen(void);
-int RTreeClose(RTree_t * rtp);
-Node_t *RTreeNewIndex(RTree_t * rtp);
-LeafList_t *RTreeSearch(RTree_t *, Node_t *, Rect_t *);
-int RTreeInsert(RTree_t *, Rect_t *, void *, Node_t **, int);
-int RTreeDelete(RTree_t *, Rect_t *, void *, Node_t **);
+void RTreeClose(RTree_t *rtp);
+Node_t *RTreeNewIndex(void);
+LeafList_t *RTreeSearch(RTree_t *, Node_t *, Rect_t);
+int RTreeInsert(RTree_t *, Rect_t, void *, Node_t **);
 
-LeafList_t *RTreeNewLeafList(Leaf_t * lp);
-LeafList_t *RTreeLeafListAdd(LeafList_t * llp, Leaf_t * lp);
 void RTreeLeafListFree(LeafList_t * llp);
 
 #ifdef RTDEBUG
