@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -18,14 +18,15 @@
 ******************************************/
 
 #include <assert.h>
-#include <cgraph/bitarray.h>
-#include <common/memory.h>
 #include <float.h>
 #include <neatogen/bfs.h>
 #include <neatogen/dijkstra.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stdlib.h>
+#include <util/alloc.h>
+#include <util/gv_math.h>
+#include <util/bitarray.h>
 
 typedef DistType Word;
 
@@ -41,10 +42,8 @@ typedef DistType Word;
 #define insideHeap(h,i) ((i)<h->heapSize)
 #define greaterPriority(h,i,j,dist) (dist[h->data[i]]<dist[h->data[j]])
 #define assign(h,i,j,index) {h->data[i]=h->data[j]; index[h->data[i]]=i;}
-#define exchange(h,i,j,index) {int temp; \
-		temp=h->data[i]; \
-		h->data[i]=h->data[j]; \
-		h->data[j]=temp; \
+#define exchange(h,i,j,index) { \
+		SWAP(&h->data[i], &h->data[j]); \
 		index[h->data[i]]=i; \
 		index[h->data[j]]=j; \
 }
@@ -86,7 +85,7 @@ initHeap(heap * h, int startVertex, int index[], Word dist[], int n)
     int i, count;
     int j;    /* We cannot use an unsigned value in this loop */
     if (n == 1) h->data = NULL;
-    else h->data = N_GNEW(n - 1, int);
+    else h->data = gv_calloc(n - 1, sizeof(int));
     h->heapSize = n - 1;
 
     for (count = 0, i = 0; i < n; i++)
@@ -137,20 +136,19 @@ increaseKey(heap * h, int increasedVertex, Word newDist, int index[],
     index[increasedVertex] = i;
 }
 
-void dijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
+void ngdijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
 {
-    int i;
     heap H;
     int closestVertex, neighbor;
     DistType closestDist, prevClosestDist = MAX_DIST;
 
-    int *index = gcalloc(n, sizeof(int));
+    int *index = gv_calloc(n, sizeof(int));
 
     /* initial distances with edge weights: */
-    for (i = 0; i < n; i++)
+    for (int i = 0; i < n; i++)
 	dist[i] = MAX_DIST;
     dist[vertex] = 0;
-    for (i = 1; i < graph[vertex].nedges; i++)
+    for (size_t i = 1; i < graph[vertex].nedges; i++)
 	dist[graph[vertex].edges[i]] = (DistType) graph[vertex].ewgts[i];
 
     initHeap(&H, vertex, index, dist, n);
@@ -159,7 +157,7 @@ void dijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
 	closestDist = dist[closestVertex];
 	if (closestDist == MAX_DIST)
 	    break;
-	for (i = 1; i < graph[closestVertex].nedges; i++) {
+	for (size_t i = 1; i < graph[closestVertex].nedges; i++) {
 	    neighbor = graph[closestVertex].edges[i];
 	    increaseKey(&H, neighbor, closestDist +
 			(DistType)graph[closestVertex].ewgts[i], index, dist);
@@ -168,76 +166,13 @@ void dijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
     }
 
     /* For dealing with disconnected graphs: */
-    for (i = 0; i < n; i++)
+    for (int i = 0; i < n; i++)
 	if (dist[i] == MAX_DIST)	/* 'i' is not connected to 'vertex' */
 	    dist[i] = prevClosestDist + 10;
     freeHeap(&H);
     free(index);
 }
 
- /* Dijkstra bounded to nodes in *unweighted* radius */
-int
-dijkstra_bounded(int vertex, vtx_data * graph, int n, DistType * dist,
-		 int bound, int *visited_nodes)
- /* make dijkstra, but consider only nodes whose *unweighted* distance from 'vertex'  */
- /* is at most 'bound' */
- /* MON-EFFICIENT implementation, see below. */
-{
-    int num_visited_nodes;
-    int i;
-    Queue Q;
-    heap H;
-    int closestVertex, neighbor;
-    DistType closestDist;
-    int num_found = 0;
-
-    /* first, perform BFS to find the nodes in the region */
-    mkQueue(&Q, n);
-    /* remember that dist should be init. with -1's */
-    for (i = 0; i < n; i++) {
-	dist[i] = -1;		/* far, TOO COSTLY (O(n))! */
-    }
-    num_visited_nodes =
-	bfs_bounded(vertex, graph, dist, &Q, bound, visited_nodes);
-    bitarray_t node_in_neighborhood = bitarray_new(n);
-    for (i = 0; i < num_visited_nodes; i++) {
-	bitarray_set(&node_in_neighborhood, visited_nodes[i], true);
-    }
-
-    int *index = gcalloc(n, sizeof(int));
-
-    /* initial distances with edge weights: */
-    for (i = 0; i < n; i++)	/* far, TOO COSTLY (O(n))! */
-	dist[i] = MAX_DIST;
-    dist[vertex] = 0;
-    for (i = 1; i < graph[vertex].nedges; i++)
-	dist[graph[vertex].edges[i]] = (DistType) graph[vertex].ewgts[i];
-
-    /* again, TOO COSTLY (O(n)) to put all nodes in heap! */
-    initHeap(&H, vertex, index, dist, n); 
-
-    while (num_found < num_visited_nodes
-	   && extractMax(&H, &closestVertex, index, dist)) {
-	if (bitarray_get(node_in_neighborhood, closestVertex)) {
-	    num_found++;
-	}
-	closestDist = dist[closestVertex];
-	if (closestDist == MAX_DIST)
-	    break;
-	for (i = 1; i < graph[closestVertex].nedges; i++) {
-	    neighbor = graph[closestVertex].edges[i];
-	    increaseKey(&H, neighbor, closestDist +
-			(DistType)graph[closestVertex].ewgts[i], index, dist);
-	}
-    }
-
-    bitarray_reset(&node_in_neighborhood);
-    freeHeap(&H);
-    free(index);
-    freeQueue(&Q);
-    return num_visited_nodes;
-}
-
 static void heapify_f(heap * h, int i, int index[], float dist[])
 {
     int l, r, largest;
@@ -264,7 +199,7 @@ initHeap_f(heap * h, int startVertex, int index[], float dist[], int n)
 {
     int i, count;
     int j;			/* We cannot use an unsigned value in this loop */
-    h->data = N_GNEW(n - 1, int);
+    h->data = gv_calloc(n - 1, sizeof(int));
     h->heapSize = n - 1;
 
     for (count = 0, i = 0; i < n; i++)
@@ -321,19 +256,16 @@ increaseKey_f(heap * h, int increasedVertex, float newDist, int index[],
  */
 void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
 {
-    int i;
     heap H;
     int closestVertex = 0, neighbor;
     float closestDist;
-    int *index;
-
-    index = N_GNEW(n, int);
+    int *index = gv_calloc(n, sizeof(int));
 
     /* initial distances with edge weights: */
-    for (i = 0; i < n; i++)
+    for (int i = 0; i < n; i++)
 	dist[i] = FLT_MAX;
     dist[vertex] = 0;
-    for (i = 1; i < graph[vertex].nedges; i++)
+    for (size_t i = 1; i < graph[vertex].nedges; i++)
 	dist[graph[vertex].edges[i]] = graph[vertex].ewgts[i];
 
     initHeap_f(&H, vertex, index, dist, n);
@@ -342,7 +274,7 @@ void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
 	closestDist = dist[closestVertex];
 	if (closestDist == FLT_MAX)
 	    break;
-	for (i = 1; i < graph[closestVertex].nedges; i++) {
+	for (size_t i = 1; i < graph[closestVertex].nedges; i++) {
 	    neighbor = graph[closestVertex].edges[i];
 	    increaseKey_f(&H, neighbor, closestDist + graph[closestVertex].ewgts[i],
 			  index, dist);
@@ -358,8 +290,8 @@ void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
 // returns the number of terms built
 int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
     heap h;
-    int *indices = N_GNEW(graph->n, int);
-    float *dists = N_GNEW(graph->n, float);
+    int *indices = gv_calloc(graph->n, sizeof(int));
+    float *dists = gv_calloc(graph->n, sizeof(float));
     for (size_t i= 0; i < graph->n; i++) {
         dists[i] = FLT_MAX;
     }
@@ -391,7 +323,7 @@ int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
              i++) {
             size_t target = graph->targets[i];
             float weight = graph->weights[i];
-            assert(target <= (size_t)INT_MAX);
+            assert(target <= INT_MAX);
             increaseKey_f(&h, (int)target, d+weight, indices, dists);
         }
     }
