@@ -12,6 +12,7 @@
 
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/api.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -20,12 +21,6 @@ extern "C" {
 #include <neatogen/poly.h>
 #include <neatogen/voronoi.h>
 
-#if !defined(__CYGWIN__) && defined(__GNUC__) && !defined(__MINGW32__)
-#define INTERNAL __attribute__((visibility("hidden")))
-#else
-#define INTERNAL /* nothing */
-#endif
-
 /// info concerning site
 typedef struct {
   Agnode_t *node; ///< libgraph node
@@ -40,9 +35,7 @@ typedef struct {
 extern Info_t *nodeInfo;
 
 /// insert vertex into sorted list
-INTERNAL void addVertex(Site *, double, double);
-
-#undef INTERNAL
+PRIVATE void addVertex(Site *, double, double);
 
 #ifdef __cplusplus
 }
