@@ -10,18 +10,14 @@
 
 #pragma once
 
+#include <util/api.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include <neatogen/defs.h>
 
-#if !defined(__CYGWIN__) && defined(__GNUC__) && !defined(__MINGW32__)
-#define INTERNAL __attribute__((visibility("hidden")))
-#else
-#define INTERNAL /* nothing */
-#endif
-
 #define tolerance_cg 1e-3
 
 #define DFLT_ITERATIONS 200
@@ -36,7 +32,7 @@ extern "C" {
 
     /* Full dense stress optimization (equivalent to Kamada-Kawai's energy) */
     /* Slowest and most accurate optimization */
-INTERNAL int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse representation */
+PRIVATE int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse representation */
 					      int n,	/* Number of nodes */
 					      double **coords,	/* coordinates of nodes (output layout)  */
 					      node_t **nodes,	/* original nodes  */
@@ -46,13 +42,11 @@ INTERNAL int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in
 					      int maxi	/* max iterations */
 	);
 
-INTERNAL float *compute_apsp_packed(vtx_data * graph, int n);
-INTERNAL float *compute_apsp_artificial_weights_packed(vtx_data *graph, int n);
-INTERNAL float* circuitModel(vtx_data * graph, int nG);
-INTERNAL float* mdsModel (vtx_data * graph, int nG);
-INTERNAL int initLayout(int n, int dim, double **coords, node_t **nodes);
-
-#undef INTERNAL
+PRIVATE float *compute_apsp_packed(vtx_data * graph, int n);
+PRIVATE float *compute_apsp_artificial_weights_packed(vtx_data *graph, int n);
+PRIVATE float* circuitModel(vtx_data * graph, int nG);
+PRIVATE float* mdsModel (vtx_data * graph, int nG);
+PRIVATE int initLayout(int n, int dim, double **coords, node_t **nodes);
 
 #ifdef __cplusplus
 }
