@@ -36,6 +36,7 @@
 #include <common/pointset.h>
 #include <util/alloc.h>
 #include <util/exit.h>
+#include <util/gv_math.h>
 #include <util/list.h>
 #include <util/unused.h>
 
@@ -52,7 +53,10 @@ int odb_flags;
 #endif
 
 #define CELL(n) ((cell*)ND_alg(n))
-#define MID(a,b) (((a)+(b))/2.0)
+
+static double MID(double a, double b) {
+  return (a + b) / 2.0;
+}
 
 /* cellOf:
  * Given 2 snodes sharing a cell, return the cell.
@@ -65,13 +69,8 @@ cellOf (snode* p, snode* q)
     return p->cells[1];
 }
 
-static pointf
-midPt (cell* cp)
-{
-    pointf p;
-    p.x = MID(cp->bb.LL.x,cp->bb.UR.x);
-    p.y = MID(cp->bb.LL.y,cp->bb.UR.y);
-    return p;
+static pointf midPt(const cell *cp) {
+  return mid_pointf(cp->bb.LL, cp->bb.UR);
 }
 
 /* sidePt:
@@ -252,7 +251,7 @@ typedef struct {
 static void freeChannel(void *chan) {
     channel *cp = chan;
     free_graph (cp->G);
-    seg_list_free(&cp->seg_list);
+    LIST_FREE(&cp->seg_list);
     free (cp);
 }
 
@@ -288,9 +287,7 @@ static int chancmpid(void *k1, void *k2) {
 static int dcmpid(void *k1, void *k2) {
   const double *key1 = k1;
   const double *key2 = k2;
-  if (*key1 > *key2) return 1;
-  if (*key1 < *key2) return -1;
-  return 0;
+  return fcmp(*key1, *key2);
 }   
 
 static Dtdisc_t chanDisc = {
@@ -402,8 +399,8 @@ extractVChans (maze* mp)
 static void
 insertChan (channel* chan, segment* seg)
 {
-    seg->ind_no = seg_list_size(&chan->seg_list);
-    seg_list_append(&chan->seg_list, seg);
+    seg->ind_no = LIST_SIZE(&chan->seg_list);
+    LIST_APPEND(&chan->seg_list, seg);
 }
 
 static channel*
@@ -508,16 +505,16 @@ static void putSeg (FILE* fp, segment* seg)
 }
 
 static UNUSED void dumpChanG(channel *cp, double v) {
-  if (seg_list_size(&cp->seg_list) < 2) return;
+  if (LIST_SIZE(&cp->seg_list) < 2) return;
   fprintf (stderr, "channel %.0f (%f,%f)\n", v, cp->p.p1, cp->p.p2);
-  for (size_t k = 0; k < seg_list_size(&cp->seg_list); ++k) {
+  for (size_t k = 0; k < LIST_SIZE(&cp->seg_list); ++k) {
     const adj_list_t adj = cp->G->vertices[k].adj_list;
-    if (adj_list_is_empty(&adj)) continue;
-    putSeg(stderr, seg_list_get(&cp->seg_list, k));
+    if (LIST_IS_EMPTY(&adj)) continue;
+    putSeg(stderr, LIST_GET(&cp->seg_list, k));
     fputs (" ->\n", stderr);
-    for (size_t i = 0; i < adj_list_size(&adj); ++i) {
+    for (size_t i = 0; i < LIST_SIZE(&adj); ++i) {
       fputs ("     ", stderr);
-      putSeg(stderr, seg_list_get(&cp->seg_list, adj_list_get(&adj, i)));
+      putSeg(stderr, LIST_GET(&cp->seg_list, LIST_GET(&adj, i)));
       fputs ("\n", stderr);
     }
   }
@@ -535,13 +532,13 @@ assignTrackNo (Dt_t* chans)
 	lp = ((chanItem*)l1)->chans;
 	for (l2 = dtflatten (lp); l2; l2 = dtlink(lp,l2)) {
 	    cp = (channel*)l2;
-	    if (!seg_list_is_empty(&cp->seg_list)) {
+	    if (!LIST_IS_EMPTY(&cp->seg_list)) {
 #ifdef DEBUG
     if (odb_flags & ODB_CHANG) dumpChanG (cp, ((chanItem*)l1)->v);
 #endif
 		top_sort (cp->G);
-		for (size_t k = 0; k < seg_list_size(&cp->seg_list); ++k)
-		    seg_list_get(&cp->seg_list, k)->track_no = cp->G->vertices[k].topsort_order+1;
+		for (size_t k = 0; k < LIST_SIZE(&cp->seg_list); ++k)
+		    LIST_GET(&cp->seg_list, k)->track_no = cp->G->vertices[k].topsort_order+1;
 	    }
    	}
     }
@@ -559,7 +556,7 @@ create_graphs(Dt_t* chans)
 	lp = ((chanItem*)l1)->chans;
 	for (l2 = dtflatten (lp); l2; l2 = dtlink(lp,l2)) {
 	    cp = (channel*)l2;
-	    cp->G = make_graph(seg_list_size(&cp->seg_list));
+	    cp->G = make_graph(LIST_SIZE(&cp->seg_list));
    	}
     }
 }
@@ -612,47 +609,46 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
     if (S2->p.p1 < S1->p.p1 && S1->p.p1 < S2->p.p2)
 	return -1*overlapSeg (S2, S1, T1, T2);
     if (S1->p.p1 == S2->p.p1) {
-	if(S1->p.p2==S2->p.p2) {
-	    if (S1->l1 == S2->l1 && S1->l2 == S2->l2)
-		return 0;
-	    if (S2->l1 == S2->l2) {
-		if (S2->l1 == T1) return 1;
-		if (S2->l1 == T2) return -1;
-		if (S1->l1 != T1 && S1->l2 != T1) return 1;
-		if (S1->l1 != T2 && S1->l2 != T2) return -1;
-		return 0;
-	    }
-	    if (S2->l1 == T1 && S2->l2 == T2) {
-		if (S1->l1 != T1 && S1->l2 == T2) return 1;
-		if (S1->l1 == T1 && S1->l2 != T2) return -1;
-		return 0;
-	    }
-	    if (S2->l2 == T1 && S2->l1 == T2) {
-		if (S1->l2 != T1 && S1->l1 == T2) return 1;
-		if (S1->l2 == T1 && S1->l1 != T2) return -1;
-		return 0;
-	    }
-	    if (S2->l1 == B_NODE && S2->l2 == T1) {
-		return ellSeg (S1->l1, S1->l2, T1);
-	    }
-	    if (S2->l1 == B_NODE && S2->l2 == T2) {
-		return -1*ellSeg (S1->l1, S1->l2, T2);
-	    }
-	    if (S2->l1 == T1 && S2->l2 == B_NODE) {
-		return ellSeg (S1->l2, S1->l1, T1);
-	    }
-	    /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
-	    return -1 * ellSeg(S1->l2, S1->l1, T2);
-	}
 	if (S1->p.p2 < S2->p.p2) {
 	    if(S1->l2==T1)
 		return eqEndSeg (S2->l1, S1->l1, T1, T2);
 	    return -1 * eqEndSeg(S2->l1, S1->l1, T1, T2);
 	}
-	/* S1->p.p2>S2->p.p2 */
-	if (S2->l2 == T2)
-	    return eqEndSeg(S1->l1, S2->l1, T1, T2);
-	return -1 * eqEndSeg(S1->l1, S2->l1, T1, T2);
+	if (S1->p.p2 > S2->p.p2) {
+	    if (S2->l2 == T2)
+		return eqEndSeg(S1->l1, S2->l1, T1, T2);
+	    return -1 * eqEndSeg(S1->l1, S2->l1, T1, T2);
+	}
+	if (S1->l1 == S2->l1 && S1->l2 == S2->l2)
+	    return 0;
+	if (S2->l1 == S2->l2) {
+	    if (S2->l1 == T1) return 1;
+	    if (S2->l1 == T2) return -1;
+	    if (S1->l1 != T1 && S1->l2 != T1) return 1;
+	    if (S1->l1 != T2 && S1->l2 != T2) return -1;
+	    return 0;
+	}
+	if (S2->l1 == T1 && S2->l2 == T2) {
+	    if (S1->l1 != T1 && S1->l2 == T2) return 1;
+	    if (S1->l1 == T1 && S1->l2 != T2) return -1;
+	    return 0;
+	}
+	if (S2->l2 == T1 && S2->l1 == T2) {
+	    if (S1->l2 != T1 && S1->l1 == T2) return 1;
+	    if (S1->l2 == T1 && S1->l1 != T2) return -1;
+	    return 0;
+	}
+	if (S2->l1 == B_NODE && S2->l2 == T1) {
+	    return ellSeg (S1->l1, S1->l2, T1);
+	}
+	if (S2->l1 == B_NODE && S2->l2 == T2) {
+	    return -1*ellSeg (S1->l1, S1->l2, T2);
+	}
+	if (S2->l1 == T1 && S2->l2 == B_NODE) {
+	    return ellSeg (S1->l2, S1->l1, T1);
+	}
+	/* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
+	return -1 * ellSeg(S1->l2, S1->l1, T2);
     }
     if (S1->p.p2 == S2->p.p1) {
 	if (S1->l2 == S2->l1) return 0;
@@ -697,13 +693,12 @@ static int
 add_edges_in_G(channel* cp)
 {
     seg_list_t *seg_list = &cp->seg_list;
-    const size_t size = seg_list_size(&cp->seg_list);
+    const size_t size = LIST_SIZE(&cp->seg_list);
     rawgraph* G = cp->G;
 
     for (size_t x = 0; x + 1 < size; ++x) {
 	for (size_t y = x + 1; y < size; ++y) {
-	    const int cmp = seg_cmp(seg_list_get(seg_list, x),
-	                            seg_list_get(seg_list, y));
+	    const int cmp = seg_cmp(LIST_GET(seg_list, x), LIST_GET(seg_list, y));
 	    if (cmp == -2) {
 		return -1;
 	    } else if (cmp > 0) {
@@ -724,7 +719,7 @@ add_np_edges (Dt_t* chans)
 	Dt_t *const lp = ((chanItem*)l1)->chans;
 	for (Dtlink_t *l2 = dtflatten(lp); l2; l2 = dtlink(lp, l2)) {
 	    channel *const cp = (channel*)l2;
-	    if (!seg_list_is_empty(&cp->seg_list))
+	    if (!LIST_IS_EMPTY(&cp->seg_list))
 		if (add_edges_in_G(cp)) {
 		  return -1;
 		}
@@ -954,35 +949,35 @@ addPEdges (channel* cp, maze* mp)
     rawgraph* G = cp->G;
     seg_list_t *segs = &cp->seg_list;
 
-    for(size_t i = 0; i + 1 < seg_list_size(&cp->seg_list); ++i) {
-	for(size_t j = i + 1; j < seg_list_size(&cp->seg_list); ++j) {
+    for(size_t i = 0; i + 1 < LIST_SIZE(&cp->seg_list); ++i) {
+	for(size_t j = i + 1; j < LIST_SIZE(&cp->seg_list); ++j) {
 	    if (!edge_exists(G,i,j) && !edge_exists(G,j,i)) {
-		if (is_parallel(seg_list_get(segs, i), seg_list_get(segs, j))) {
+		if (is_parallel(LIST_GET(segs, i), LIST_GET(segs, j))) {
 		/* get_directions */
-		    if (seg_list_get(segs, i)->prev == 0) {
-			if (seg_list_get(segs, j)->prev == 0)
+		    if (LIST_GET(segs, i)->prev == 0) {
+			if (LIST_GET(segs, j)->prev == 0)
 			    dir = 0;
 			else
 			    dir = 1;
 		    }
-		    else if (seg_list_get(segs, j)->prev == 0) {
+		    else if (LIST_GET(segs, j)->prev == 0) {
 			dir = 1;
 		    }
 		    else {
-			if (seg_list_get(segs, i)->prev->comm_coord ==
-			    seg_list_get(segs, j)->prev->comm_coord)
+			if (LIST_GET(segs, i)->prev->comm_coord ==
+			    LIST_GET(segs, j)->prev->comm_coord)
 			    dir = 0;
 			else
 			    dir = 1;
 		    }
 
-		    if (decide_point(&p, seg_list_get(segs, i), seg_list_get(segs, j), 0, dir)
+		    if (decide_point(&p, LIST_GET(segs, i), LIST_GET(segs, j), 0, dir)
 		        != 0) {
 			return -1;
 		    }
 		    hops.a = p.a;
 		    prec1 = p.b;
-		    if (decide_point(&p, seg_list_get(segs, i), seg_list_get(segs, j), 1,
+		    if (decide_point(&p, LIST_GET(segs, i), LIST_GET(segs, j), 1,
 		                     1 - dir) != 0) {
 			return -1;
 		    }
@@ -990,36 +985,36 @@ addPEdges (channel* cp, maze* mp)
 		    prec2 = p.b;
 
 		    if (prec1 == -1) {
-			set_parallel_edges(seg_list_get(segs, j), seg_list_get(segs, i), dir, 0,
+			set_parallel_edges(LIST_GET(segs, j), LIST_GET(segs, i), dir, 0,
 			                   hops.a, mp);
-			set_parallel_edges(seg_list_get(segs, j), seg_list_get(segs, i), 1 - dir, 1,
+			set_parallel_edges(LIST_GET(segs, j), LIST_GET(segs, i), 1 - dir, 1,
 			                   hops.b, mp);
 			if(prec2==1)
-			    removeEdge(seg_list_get(segs, i), seg_list_get(segs, j), 1 - dir, mp);
+			    removeEdge(LIST_GET(segs, i), LIST_GET(segs, j), 1 - dir, mp);
 		    } else if (prec1 == 0) {
 			if (prec2 == -1) {
-			    set_parallel_edges(seg_list_get(segs, j), seg_list_get(segs, i), dir, 0,
+			    set_parallel_edges(LIST_GET(segs, j), LIST_GET(segs, i), dir, 0,
 			                       hops.a, mp);
-			    set_parallel_edges(seg_list_get(segs, j), seg_list_get(segs, i), 1 - dir,
+			    set_parallel_edges(LIST_GET(segs, j), LIST_GET(segs, i), 1 - dir,
 			                       1, hops.b, mp);
 			} else if (prec2 == 0) {
-			    set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 0, dir,
+			    set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 0, dir,
 			                       hops.a, mp);
-			    set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 1,
+			    set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 1,
 			                       1 - dir, hops.b, mp);
 			} else if (prec2 == 1) {
-			    set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 0, dir,
+			    set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 0, dir,
 			                       hops.a, mp);
-			    set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 1,
+			    set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 1,
 			                       1 - dir, hops.b, mp);
 			}
 		    } else if (prec1 == 1) {
-			set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 0, dir,
+			set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 0, dir,
 			                   hops.a, mp);
-			set_parallel_edges(seg_list_get(segs, i), seg_list_get(segs, j), 1, 1 - dir,
+			set_parallel_edges(LIST_GET(segs, i), LIST_GET(segs, j), 1, 1 - dir,
 			                   hops.b, mp);
 			if(prec2==-1)
-			    removeEdge(seg_list_get(segs, i), seg_list_get(segs, j), 1 - dir, mp);
+			    removeEdge(LIST_GET(segs, i), LIST_GET(segs, j), 1 - dir, mp);
 		    }
 		}
 	    }
@@ -1078,25 +1073,22 @@ static double
 vtrack (segment* seg, maze* m)
 {
   channel* chp = chanSearch(m->vchans, seg);
-  const double f = (double)seg->track_no / ((double)seg_list_size(&chp->seg_list) + 1);
-  double left = chp->cp->bb.LL.x;
-  double right = chp->cp->bb.UR.x;
-  return left + f*(right-left);
+  const double f = seg->track_no / ((double)LIST_SIZE(&chp->seg_list) + 1);
+  const pointf interp = interpolate_pointf(f, chp->cp->bb.LL, chp->cp->bb.UR);
+  return interp.x;
 }
 
 static double htrack(segment *seg, maze *m) {
   channel* chp = chanSearch(m->hchans, seg);
-  double f = 1.0 - (double)seg->track_no / ((double)seg_list_size(&chp->seg_list) + 1);
+  double f = 1.0 - seg->track_no / ((double)LIST_SIZE(&chp->seg_list) + 1);
   double lo = chp->cp->bb.LL.y;
   double hi = chp->cp->bb.UR.y;
   return round(lo + f * (hi - lo));
 }
 
-DEFINE_LIST(points, pointf)
-
 static void attachOrthoEdges(maze *mp, size_t n_edges, route* route_list,
                              splineInfo *sinfo, epair_t es[], bool doLbls) {
-    points_t ispline = {0};
+    LIST(pointf) ispline = {0};
     textlabel_t* lbl;
 
     for (size_t irte = 0; irte < n_edges; irte++) {
@@ -1106,7 +1098,7 @@ static void attachOrthoEdges(maze *mp, size_t n_edges, route* route_list,
 
 	route rte = route_list[irte];
 	size_t npts = 1 + 3*rte.n;
-	points_reserve(&ispline, npts);
+	LIST_RESERVE(&ispline, npts);
 	    
 	segment *seg = rte.segs;
 	if (seg == NULL) {
@@ -1119,8 +1111,8 @@ static void attachOrthoEdges(maze *mp, size_t n_edges, route* route_list,
 	else {
 		p = (pointf){.x = p1.x, .y = htrack(seg, mp)};
 	}
-	points_append(&ispline, p);
-	points_append(&ispline, p);
+	LIST_APPEND(&ispline, p);
+	LIST_APPEND(&ispline, p);
 
 	for (size_t i = 1;i<rte.n;i++) {
 		seg = rte.segs+i;
@@ -1128,9 +1120,9 @@ static void attachOrthoEdges(maze *mp, size_t n_edges, route* route_list,
 		    p.x = vtrack(seg, mp);
 		else
 		    p.y = htrack(seg, mp);
-		points_append(&ispline, p);
-		points_append(&ispline, p);
-		points_append(&ispline, p);
+		LIST_APPEND(&ispline, p);
+		LIST_APPEND(&ispline, p);
+		LIST_APPEND(&ispline, p);
 	}
 
 	if (seg->isVert) {
@@ -1139,17 +1131,17 @@ static void attachOrthoEdges(maze *mp, size_t n_edges, route* route_list,
 	else {
 		p = (pointf){.x = q1.x, .y = htrack(seg, mp)};
 	}
-	points_append(&ispline, p);
-	points_append(&ispline, p);
+	LIST_APPEND(&ispline, p);
+	LIST_APPEND(&ispline, p);
 	if (Verbose > 1)
 	    fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
-	clip_and_install(e, aghead(e), points_front(&ispline), points_size(&ispline),
+	clip_and_install(e, aghead(e), LIST_FRONT(&ispline), LIST_SIZE(&ispline),
 	                 sinfo);
 	if (doLbls && (lbl = ED_label(e)) && !lbl->set)
 	    addEdgeLabels(e);
-	points_clear(&ispline);
+	LIST_CLEAR(&ispline);
     }
-    points_free(&ispline);
+    LIST_FREE(&ispline);
 }
 
 static int
