@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -62,17 +62,6 @@ extern "C" {
 	  } \
 	}
 
-/* extensions to sfvprintf/sfvscanf */
-#define FP_SET(fp,fn)	(fp < 0 ? (fn += 1) : (fn = fp) )
-#define FP_WIDTH	0
-#define FP_PRECIS	1
-#define FP_BASE		2
-#define FP_STR		3
-#define FP_SIZE		4
-#define FP_INDEX	5	/* index size   */
-
-    typedef struct _fmt_s Fmt_t;
-    typedef struct _fmtpos_s Fmtpos_t;
     typedef union {
 	int i, *ip;
 	long l, *lp;
@@ -80,9 +69,9 @@ extern "C" {
 	unsigned ui;
 	ulong ul;
 	ushort uh;
-	Sflong_t ll, *llp;
-	Sfulong_t lu;
-	Sfdouble_t ld;
+	long long ll, *llp;
+	unsigned long long lu;
+	long double ld;
 	double d;
 	float f;
 	char c, *s, **sp;
@@ -90,38 +79,18 @@ extern "C" {
 	Sffmt_t *ft;
     } Argv_t;
 
-    struct _fmt_s {
-	char *form;		/* format string                */
-	va_list args;		/* corresponding arglist        */
-
-	char *oform;		/* original format string       */
-	va_list oargs;		/* original arg list            */
-	int argn;		/* number of args already used  */
-	Fmtpos_t *fp;		/* position list                */
-
-	Sffmt_t *ft;		/* formatting environment       */
-	Fmt_t *next;		/* stack frame pointer          */
-    };
-
-    struct _fmtpos_s {
-	Sffmt_t ft;		/* environment                  */
-	Argv_t argv;		/* argument value               */
-	int fmt;		/* original format              */
-	int need[FP_INDEX];	/* positions depending on       */
-    };
-
 #define LEFTP		'('
 #define RIGHTP		')'
 #define QUOTE		'\''
 
-#define FMTSET(ft, frm,ags, fv, sz, flgs, wid,pr,bs, ts,ns) \
-	((ft->form = (char*)frm), va_copy(ft->args,ags), \
+#define FMTSET(ft, frm, fv, sz, flgs, wid,pr,bs, ts,ns) \
+	((ft->form = (char*)frm), \
 	 (ft->fmt = fv), (ft->size = sz), \
 	 (ft->flags = (flgs&SFFMT_SET)), \
 	 (ft->width = wid), (ft->precis = pr), (ft->base = bs), \
 	 (ft->t_str = ts), (ft->n_str = ns) )
-#define FMTGET(ft, frm,ags, fv, sz, flgs, wid,pr,bs) \
-	((frm = ft->form), va_copy(ags,ft->args), (fv = ft->fmt), (sz = ft->size), \
+#define FMTGET(ft, frm, fv, sz, flgs, wid,pr,bs) \
+	((frm = ft->form), (fv = ft->fmt), (sz = ft->size), \
 	 (flgs = (flgs&~(SFFMT_SET))|(ft->flags&SFFMT_SET)), \
 	 (wid = ft->width), (pr = ft->precis), (bs = ft->base) )
 #define FMTCMP(sz, type, maxtype) \
@@ -163,8 +132,8 @@ extern "C" {
 #define _Sfcv64		(_Sftable.sf_cv64)
 #define _Sftype		(_Sftable.sf_type)
     typedef struct _sftab_ {
-	Sfdouble_t sf_pos10[SF_MAXEXP10];	/* positive powers of 10        */
-	Sfdouble_t sf_neg10[SF_MAXEXP10];	/* negative powers of 10        */
+	long double sf_pos10[SF_MAXEXP10]; ///< positive powers of 10
+	long double sf_neg10[SF_MAXEXP10]; ///< negative powers of 10
 	uchar sf_dec[200];	/* ascii reps of values < 100   */
 	char *sf_digits;	/* digits for general bases     */
 	int sf_cvinit;		/* initialization state         */
@@ -220,10 +189,6 @@ extern "C" {
 	  } \
 	}
 
-// handy function
-#undef min
-#define min(x,y)	((x) < (y) ? (x) : (y))
-
     extern Sftab_t _Sftable;
 
     extern char *_sfcvt(void *, int, int *, int *, int);
