@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -11,6 +11,7 @@
 #include	<limits.h>
 #include	<sfio/sfhdr.h>
 #include	<stddef.h>
+#include	<util/gv_ctype.h>
 
 /*	Dealing with $ argument addressing stuffs.
 **
@@ -19,7 +20,7 @@
 
 static char *sffmtint(const char *str, int *v)
 {
-    for (*v = 0; isdigit((int)*str); ++str)
+    for (*v = 0; gv_isdigit(*str); ++str)
 	*v = *v * 10 + (*str - '0');
     *v -= 1;
     return (char *) str;
