@@ -74,7 +74,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 
     Argv_t argv;
 
-    int argp, argn;
+    int argn;
 
     void *value;		/* location to assign scanned value */
     const char *t_str;
@@ -146,7 +146,6 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 	t_str = NULL;
 	n_str = 0;
 	value = NULL;
-	argp = -1;
 
       loop_flags:		/* LOOP FOR FLAGS, WIDTH, BASE, TYPE */
 	switch ((fmt = *form++)) {
@@ -169,7 +168,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 			n_str = (form - 1) - t_str;
 		    else {
 			t_str = _Sffmtintf(t_str + 1, &n);
-			FP_SET(-1, argn);
+			++argn;
 
 			FMTSET(ft, form, LEFTP, 0, 0, 0, 0, 0, NULL, 0);
 			n = ft->extf(&argv, ft);
@@ -197,7 +196,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 		goto dot_size;
 	    } else if (*form == '*') {
 		form = _Sffmtintf(form + 1, &n);
-		n = FP_SET(-1, argn);
+		n = ++argn;
 
 		FMTSET(ft, form, '.', dot, 0, 0, 0, 0, NULL, 0);
 		if (ft->extf(&argv, ft) < 0)
@@ -239,7 +238,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 		    size = size * 10 + (n - '0');
 	    } else if (*form == '*') {
 		form = _Sffmtintf(form + 1, &n);
-		n = FP_SET(-1, argn);
+		n = ++argn;
 
 		FMTSET(ft, form, 'I', sizeof(int), 0, 0, 0, 0, NULL, 0);
 		if (ft->extf(&argv, ft) < 0)
@@ -303,7 +302,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 	    }
 	}
 
-	argp = FP_SET(argp, argn);
+	++argn;
 	FMTSET(ft, form, fmt, size, flags, width, 0, base, t_str, n_str);
 	v = ft->extf(&argv, ft);
 
