@@ -12,6 +12,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <util/gv_math.h>
 
 #ifdef __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__
 #if __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 20000
@@ -131,29 +132,27 @@ static void quartzgen_begin_page(GVJ_t * job)
 	case FORMAT_PDF:
 	    {
 		/* create the auxiliary info for PDF content, author and title */
-		CFStringRef auxiliaryKeys[] = {
+		const void *auxiliaryKeys[] = {
 		    kCGPDFContextCreator,
 		    kCGPDFContextTitle
 		};
-		CFStringRef auxiliaryValues[] = {
-		    CFStringCreateWithFormat(kCFAllocatorDefault, NULL,
+		const void *auxiliaryValues[] = {
+		    CFStringCreateWithFormat(NULL, NULL,
 					     CFSTR("%s %s"),
 					     job->common->info[0],
 					     job->common->info[1]),
 		    job->obj->type ==
 			ROOTGRAPH_OBJTYPE ?
-			CFStringCreateWithBytesNoCopy(kCFAllocatorDefault,
-						      (const UInt8 *) agnameof(job->obj->u.g),
-						      strlen(agnameof(job->obj->u.g)),
+			CFStringCreateWithCStringNoCopy(NULL,
+						      agnameof(job->obj->u.g),
 						      kCFStringEncodingUTF8,
-						      false,
 						      kCFAllocatorNull)
 			: CFSTR("")
 		};
 		CFDictionaryRef auxiliaryInfo =
-		    CFDictionaryCreate(kCFAllocatorDefault,
-				       (const void **) &auxiliaryKeys,
-				       (const void **) &auxiliaryValues,
+		    CFDictionaryCreate(NULL,
+				       auxiliaryKeys,
+				       auxiliaryValues,
 				       sizeof(auxiliaryValues) /
 				       sizeof(auxiliaryValues[0]),
 				       &kCFTypeDictionaryKeyCallBacks,
@@ -178,9 +177,11 @@ static void quartzgen_begin_page(GVJ_t * job)
 
 	default:		/* bitmap formats */
 	    {
-		size_t bytes_per_row =
-		    (job->width * BYTES_PER_PIXEL +
-		     BYTE_ALIGN) & ~BYTE_ALIGN;
+		size_t bytes_per_row = job->width * BYTES_PER_PIXEL;
+		// align up to a 16-byte boundary
+		if (bytes_per_row % 16 != 0) {
+		    bytes_per_row += 16 - (bytes_per_row % 16);
+		}
 
 		void *buffer = NULL;
 
@@ -276,8 +277,7 @@ static void quartzgen_begin_anchor(GVJ_t * job, char *url, char *tooltip,
     if (url && url_map) {
 	/* set up the hyperlink to the given url */
 	CGContextRef context = job->context;
-	CFURLRef uri =
-	    CFURLCreateWithBytes(kCFAllocatorDefault, (const UInt8 *) url,
+	CFURLRef uri = CFURLCreateWithBytes(NULL, (const UInt8 *)url,
 				 strlen(url), kCFStringEncodingUTF8, NULL);
 	CGPDFContextSetURLForRect(context, uri,
 				  /* need to reverse the CTM on the area to get it to work */
