@@ -8,33 +8,18 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <stddef.h>
 #include <gvc/gvc.h>
 #include <gvc/gvplugin.h>
 #include <gvc/gvcjob.h>
 #include <gvc/gvcint.h>
 #include "gv_channel.h"
-
-typedef struct {
-    char* data;
-    size_t sz;       /* buffer size */
-    size_t len;      /* length of array */
-} BA;
+#include <util/agxbuf.h>
 
 static size_t gv_string_writer(GVJ_t *job, const char *s, size_t len)
 {
-    BA* bap = (BA*)(job->output_file);
-    size_t newlen = bap->len + len;
-    if (newlen > bap->sz) {
-	bap->sz *= 2;
-	if (newlen > bap->sz)
-	    bap->sz = 2*newlen;
-        bap->data = realloc(bap->data, bap->sz);
-    }
-    memcpy (bap->data+bap->len, s, len); 
-    bap->len = newlen;
-    return len;
+    agxbuf *const buffer = (agxbuf *)job->output_file;
+    return agxbput_n(buffer, s, len);
 }
 
 void gv_string_writer_init(GVC_t *gvc)
